@@ -1,22 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "archivejob.h"
-#include "archivemailinfo.h"
-#include "archivemailmanager.h"
-#include "archivemailkernel.h"
 #include "archivemailagent_debug.h"
+#include "archivemailinfo.h"
+#include "archivemailkernel.h"
+#include "archivemailmanager.h"
 
-#include <MailCommon/MailUtil>
 #include <MailCommon/BackupJob>
+#include <MailCommon/MailUtil>
 
 #include <AkonadiCore/EntityMimeTypeFilterModel>
 
-#include <KNotification>
 #include <KLocalizedString>
+#include <KNotification>
 
 ArchiveJob::ArchiveJob(ArchiveMailManager *manager, ArchiveMailInfo *info, const Akonadi::Collection &folder, bool immediate)
     : MailCommon::ScheduledJob(folder, immediate)
@@ -64,7 +64,7 @@ void ArchiveJob::execute()
             return;
         }
 
-        auto *backupJob = new MailCommon::BackupJob();
+        auto backupJob = new MailCommon::BackupJob();
         backupJob->setRootFolder(Akonadi::EntityTreeModel::updatedCollection(mManager->kernel()->collectionModel(), collection));
 
         backupJob->setSaveLocation(archivePath);
