@@ -20,18 +20,25 @@
 #include <AkonadiCore/CollectionFetchScope>
 #include <AkonadiCore/ServerManager>
 #include <AkonadiCore/Session>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
-
+#endif
 #include "followupreminderagent_debug.h"
 #include <QTimer>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
     : Akonadi::AgentBase(id)
     , mManager(new FollowUpReminderManager(this))
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("followupreminderagent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_followupreminder_agentrc") << QStringLiteral("akonadi_followupreminder_agent.notifyrc"));
     migrate.migrate();
+#endif
 
     new FollowUpReminderAgentAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/FollowUpReminder"), this, QDBusConnection::ExportAdaptors);
@@ -55,7 +62,7 @@ FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
     mTimer = new QTimer(this);
     connect(mTimer, &QTimer::timeout, this, &FollowUpReminderAgent::reload);
     // Reload all each 24hours
-    mTimer->start(24 * 60 * 60 * 1000);
+    mTimer->start(24h);
 }
 
 FollowUpReminderAgent::~FollowUpReminderAgent() = default;
@@ -106,7 +113,7 @@ void FollowUpReminderAgent::addReminder(const QString &messageId,
                                         Akonadi::Item::Id messageItemId,
                                         const QString &to,
                                         const QString &subject,
-                                        const QDate &followupDate,
+                                        QDate followupDate,
                                         Akonadi::Item::Id todoId)
 {
     auto info = new FollowUpReminder::FollowUpReminderInfo();
