@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
-#ifndef FILTERMANAGER_H
-#define FILTERMANAGER_H
+#pragma once
 
 #include <AkonadiCore/collection.h>
 #include <AkonadiCore/item.h>
@@ -34,10 +33,14 @@ public:
         Explicit = 0x4,
         BeforeOutbound = 0x8,
         AllFolders = 0x16,
-        All = Inbound | BeforeOutbound | Outbound | Explicit | AllFolders
+        All = Inbound | BeforeOutbound | Outbound | Explicit | AllFolders,
     };
 
-    enum FilterRequires { Unknown = 0, HeaderMessage = 1, FullMessage = 2 };
+    enum FilterRequires {
+        Unknown = 0,
+        HeaderMessage = 1,
+        FullMessage = 2,
+    };
 
     /**
      * Creates a new filter manager.
@@ -149,4 +152,3 @@ private:
     //@endcond
 };
 
-#endif
