@@ -36,8 +36,13 @@
 #include <KSharedConfig>
 #include <QTimer>
 
-#include <Kdelibs4ConfigMigrator>
+#include <chrono>
 
+using namespace std::chrono_literals;
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <Kdelibs4ConfigMigrator>
+#endif
 bool MailFilterAgent::isFilterableCollection(const Akonadi::Collection &collection) const
 {
     if (!collection.contentMimeTypes().contains(KMime::Message::mimeType())) {
@@ -52,9 +57,11 @@ bool MailFilterAgent::isFilterableCollection(const Akonadi::Collection &collecti
 MailFilterAgent::MailFilterAgent(const QString &id)
     : Akonadi::AgentBase(id)
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("mailfilteragent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_mailfilter_agentrc") << QStringLiteral("akonadi_mailfilter_agent.notifyrc"));
     migrate.migrate();
+#endif
 
     Akonadi::AttributeFactory::registerAttribute<Akonadi::Pop3ResourceAttribute>();
     mMailFilterKernel = new DummyKernel(this);
@@ -166,7 +173,7 @@ void MailFilterAgent::initialCollectionFetchingDone(KJob *job)
     }
     Q_EMIT status(AgentBase::Idle, i18n("Ready"));
     Q_EMIT percent(100);
-    QTimer::singleShot(2000, this, &MailFilterAgent::clearMessage);
+    QTimer::singleShot(2s, this, &MailFilterAgent::clearMessage);
 }
 
 void MailFilterAgent::clearMessage()
