@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SENDLATERCONFIGUREWIDGET_H
-#define SENDLATERCONFIGUREWIDGET_H
+#pragma once
 #include "ui_sendlaterconfigurewidget.h"
 
 #include <AkonadiCore/Item>
@@ -38,7 +37,13 @@ public:
     explicit SendLaterWidget(QWidget *parent = nullptr);
     ~SendLaterWidget() override;
 
-    enum SendLaterColumn { To = 0, Subject, SendAround, Recursive, MessageId };
+    enum SendLaterColumn {
+        To = 0,
+        Subject,
+        SendAround,
+        Recursive,
+        MessageId,
+    };
 
     void save();
     void saveTreeWidgetHeader(KConfigGroup &group);
@@ -62,4 +67,3 @@ private:
     Ui::SendLaterConfigureWidget *mWidget = nullptr;
 };
 
-#endif // SENDLATERCONFIGUREWIDGET_H
