@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SETTINGSDIALOG_H_
-#define SETTINGSDIALOG_H_
+#pragma once
 
 #include <QDialog>
 
@@ -30,10 +29,9 @@ private:
 private:
     void readConfig();
     void writeConfig();
-    QStandardItemModel *mBoxModel = nullptr;
+    QStandardItemModel *const mBoxModel;
     UnifiedMailboxManager &mBoxManager;
     MailKernel *const mKernel;
     const KSharedConfigPtr mConfig;
 };
 
-#endif
