@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef REFRESHSETTRINGSFINISHPAGE_H
-#define REFRESHSETTRINGSFINISHPAGE_H
+#pragma once
 
 #include <QWidget>
 class QPlainTextEdit;
@@ -21,7 +20,6 @@ Q_SIGNALS:
 
 private:
     void slotCleanDoneInfo(const QString &info);
-    QPlainTextEdit *mTextEdit = nullptr;
+    QPlainTextEdit *const mTextEdit;
 };
 
-#endif // REFRESHSETTRINGSFINISHPAGE_H
