@@ -38,9 +38,11 @@
 #include <QStandardPaths>
 #include <QTemporaryFile>
 #include <QUrl>
+#include <kio_version.h>
+#include <kxmlgui_version.h>
 
 #include <KConfigGroup>
-#include <KRecentFilesAction>
+#include <KRecentFilesMenu>
 
 #include <KSharedConfig>
 #include <QContextMenuEvent>
@@ -62,9 +64,6 @@ KTNEFMain::KTNEFMain(QWidget *parent)
     KConfigGroup config(KSharedConfig::openConfig(), "Settings");
     mDefaultDir = config.readPathEntry("defaultdir", QStringLiteral("/tmp/"));
 
-    config = KConfigGroup(KSharedConfig::openConfig(), "Recent Files");
-    mOpenRecentFileAction->loadEntries(config);
-
     mLastDir = mDefaultDir;
 
     // create personal temp extract dir
@@ -101,7 +100,9 @@ void KTNEFMain::setupActions()
     // File menu
     KStandardAction::open(this, &KTNEFMain::openFile, actionCollection());
 
-    mOpenRecentFileAction = KStandardAction::openRecent(this, &KTNEFMain::openRecentFile, actionCollection());
+    mOpenRecentFileMenu = new KRecentFilesMenu(this);
+    actionCollection()->addAction(QStringLiteral("ktnef_file_open_recent"), mOpenRecentFileMenu->menuAction());
+    connect(mOpenRecentFileMenu, &KRecentFilesMenu::urlTriggered, this, &KTNEFMain::openRecentFile);
 
     // Action menu
     QAction *openAction = actionCollection()->addAction(QStringLiteral("view_file"));
@@ -162,7 +163,11 @@ void KTNEFMain::setupActions()
 
 void KTNEFMain::slotConfigureKeys()
 {
+#if KXMLGUI_VERSION < QT_VERSION_CHECK(5, 84, 0)
     KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
+#else
+    KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
+#endif
 }
 
 void KTNEFMain::setupStatusbar()
@@ -218,10 +223,7 @@ void KTNEFMain::openRecentFile(const QUrl &url)
 
 void KTNEFMain::addRecentFile(const QUrl &url)
 {
-    mOpenRecentFileAction->addUrl(url);
-    KConfigGroup config(KSharedConfig::openConfig(), "Recent Files");
-    mOpenRecentFileAction->saveEntries(config);
-    config.sync();
+    mOpenRecentFileMenu->addUrl(url);
 }
 
 void KTNEFMain::viewFile()
@@ -549,8 +551,11 @@ void KTNEFMain::createOpenWithMenu(QMenu *topMenu)
     }
     KTNEFAttach *attach = mView->getSelection().at(0);
     QString mimename(attach->mimeTag());
-
+#if KIO_VERSION < QT_VERSION_CHECK(5, 83, 0)
     const KService::List offers = KFileItemActions::associatedApplications(QStringList() << mimename, QString());
+#else
+    const KService::List offers = KFileItemActions::associatedApplications(QStringList() << mimename);
+#endif
     if (!offers.isEmpty()) {
         QMenu *menu = topMenu;
         auto actionGroup = new QActionGroup(menu);
@@ -594,7 +599,7 @@ void KTNEFMain::createOpenWithMenu(QMenu *topMenu)
 
 void KTNEFMain::slotOpenWithAction(QAction *act)
 {
-    KService::Ptr app = act->data().value<KService::Ptr>();
+    auto app = act->data().value<KService::Ptr>();
 
     openWith(app);
 }
