@@ -11,8 +11,7 @@
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef MESSAGEPROPERTYDIALOG_H
-#define MESSAGEPROPERTYDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -39,4 +38,3 @@ private:
     QTreeWidget *mListView = nullptr;
 };
 
-#endif
