@@ -1,28 +1,28 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "cryptostateindicatorwidgettest.h"
-#include <QTest>
 #include "src/editor/widgets/cryptostateindicatorwidget.h"
 #include <QLabel>
-CryptoStateIndicatorWidgetTest::CryptoStateIndicatorWidgetTest(QObject *parent) : QObject(parent)
+#include <QTest>
+CryptoStateIndicatorWidgetTest::CryptoStateIndicatorWidgetTest(QObject *parent)
+    : QObject(parent)
 {
 }
 
-CryptoStateIndicatorWidgetTest::~CryptoStateIndicatorWidgetTest()
-= default;
+CryptoStateIndicatorWidgetTest::~CryptoStateIndicatorWidgetTest() = default;
 
 void CryptoStateIndicatorWidgetTest::shouldHaveDefaultValue()
 {
     CryptoStateIndicatorWidget w;
     w.show();
     QVERIFY(QTest::qWaitForWindowExposed(&w));
-    auto *signature = w.findChild<QLabel *>(QStringLiteral("signatureindicator"));
+    auto signature = w.findChild<QLabel *>(QStringLiteral("signatureindicator"));
     QVERIFY(signature);
-    auto *encryption = w.findChild<QLabel *>(QStringLiteral("encryptionindicator"));
+    auto encryption = w.findChild<QLabel *>(QStringLiteral("encryptionindicator"));
     QVERIFY(encryption);
     QVERIFY(signature->isVisible());
     QVERIFY(encryption->isVisible());
@@ -33,8 +33,8 @@ void CryptoStateIndicatorWidgetTest::shouldBeNotVisibleWhenShowAlwaysIsFalse()
     CryptoStateIndicatorWidget w;
     w.setShowAlwaysIndicator(false);
     w.show();
-    auto *signature = w.findChild<QLabel *>(QStringLiteral("signatureindicator"));
-    auto *encryption = w.findChild<QLabel *>(QStringLiteral("encryptionindicator"));
+    auto signature = w.findChild<QLabel *>(QStringLiteral("signatureindicator"));
+    auto encryption = w.findChild<QLabel *>(QStringLiteral("encryptionindicator"));
     QVERIFY(!signature->isVisible());
     QVERIFY(!encryption->isVisible());
     w.updateSignatureAndEncrypionStateIndicators(true, true);
@@ -49,8 +49,8 @@ void CryptoStateIndicatorWidgetTest::shouldVisibleWhenChangeStatus()
     w.setShowAlwaysIndicator(true);
     w.show();
     QVERIFY(QTest::qWaitForWindowExposed(&w));
-    auto *signature = w.findChild<QLabel *>(QStringLiteral("signatureindicator"));
-    auto *encryption = w.findChild<QLabel *>(QStringLiteral("encryptionindicator"));
+    auto signature = w.findChild<QLabel *>(QStringLiteral("signatureindicator"));
+    auto encryption = w.findChild<QLabel *>(QStringLiteral("encryptionindicator"));
     w.updateSignatureAndEncrypionStateIndicators(true, false);
     QVERIFY(signature->isVisible());
     QVERIFY(!encryption->isVisible());
