@@ -3,8 +3,7 @@
 
   SPDX-License-Identifier: GPL-2.0-only
 */
-#ifndef CONFIGUREAPPEARANCEPAGE_H
-#define CONFIGUREAPPEARANCEPAGE_H
+#pragma once
 
 #include "MailCommon/Tag"
 #include "configuredialog_p.h"
@@ -265,7 +264,7 @@ class KMAIL_EXPORT AppearancePage : public ConfigModuleWithTabs
 {
     Q_OBJECT
 public:
-    explicit AppearancePage(QWidget *parent = nullptr);
+    explicit AppearancePage(QWidget *parent = nullptr, const QVariantList &args = {});
 
     QString helpAnchor() const override;
 
@@ -278,4 +277,3 @@ public:
     using MessageTagTab = AppearancePageMessageTagTab;
 };
 
-#endif // CONFIGUREAPPEARANCEPAGE_H
