@@ -21,9 +21,11 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <QGpgME/CryptoConfig>
 #include <QGpgME/Protocol>
 
+#include "kcmutils_version.h"
 #include "kmail_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KPluginMetaData>
 
 #include <QButtonGroup>
 #include <QDBusConnection>
@@ -35,8 +37,8 @@ QString SecurityPage::helpAnchor() const
     return QStringLiteral("configure-security");
 }
 
-SecurityPage::SecurityPage(QWidget *parent)
-    : ConfigModuleWithTabs(parent)
+SecurityPage::SecurityPage(QWidget *parent, const QVariantList &args)
+    : ConfigModuleWithTabs(parent, args)
 {
     //
     // "Reading" tab:
@@ -370,7 +372,15 @@ void SecurityPage::WarningTab::slotReenableAllWarningsClicked()
 void SecurityPage::WarningTab::slotConfigureGnupg()
 {
     QPointer<GpgSettingsDialog> dlg(new GpgSettingsDialog(this));
-    KPageWidgetItem *page = dlg->addModule(QStringLiteral("kleopatra_config_gnupgsystem"));
+    KPageWidgetItem *page = nullptr;
+#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+    const auto plugin = KPluginMetaData::findPluginById(QStringLiteral("pim/kcms/kleopatra"), QStringLiteral("kleopatra_config_gnupgsystem"));
+    if (plugin.isValid()) {
+        page = dlg->addModule(plugin);
+    }
+#else
+    page = dlg->addModule(QStringLiteral("kleopatra_config_gnupgsystem"));
+#endif
     if (!page) {
         auto info = new QLabel(i18n("The module is missing. Please verify your installation. This module is provided by Kleopatra."), this);
         QFont font = info->font();
@@ -721,7 +731,7 @@ GpgSettingsDialog::~GpgSettingsDialog()
 
 void GpgSettingsDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "GpgSettingsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "GpgSettingsDialog");
     const QSize size = group.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -730,7 +740,7 @@ void GpgSettingsDialog::readConfig()
 
 void GpgSettingsDialog::saveConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "GpgSettingsDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "GpgSettingsDialog");
     group.writeEntry("Size", size());
     group.sync();
 }
