@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KMKNOTIFY_H
-#define KMKNOTIFY_H
+#pragma once
 
 #include <QDialog>
 class QComboBox;
@@ -30,10 +29,9 @@ private:
     void initCombobox();
     void writeConfig();
     void readConfig();
-    QComboBox *m_comboNotify = nullptr;
-    KNotifyConfigWidget *m_notifyWidget = nullptr;
+    QComboBox *const m_comboNotify;
+    KNotifyConfigWidget *const m_notifyWidget;
     bool m_changed = false;
 };
 }
 
-#endif /* KMKNOTIFY_H */
