@@ -2,8 +2,7 @@
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
-#ifndef FOLDERSHORTCUTACTIONMANAGER_H
-#define FOLDERSHORTCUTACTIONMANAGER_H
+#pragma once
 
 #include "kmail_export.h"
 
@@ -77,4 +76,3 @@ private:
 };
 }
 
-#endif
