@@ -9,8 +9,7 @@
     SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef KMAIL_XFACECONFIGURATOR_H
-#define KMAIL_XFACECONFIGURATOR_H
+#pragma once
 
 #include <QWidget>
 
@@ -46,10 +45,9 @@ private:
     void slotDelayedSelectFromAddressbook(KJob *);
     void slotUpdateXFace();
 
-    QCheckBox *mEnableCheck = nullptr;
+    QCheckBox *const mEnableCheck;
     KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
-    QLabel *mXFaceLabel = nullptr;
+    QLabel *const mXFaceLabel;
 };
 } // namespace KMail
 
-#endif // KMAIL_XFACECONFIGURATOR_H
