@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,12 +13,12 @@
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/AgentInstanceCreateJob>
-#include <AkonadiWidgets/AgentTypeDialog>
-#include <AkonadiCore/CollectionFetchScope>
-#include <AkonadiCore/AgentFilterProxyModel>
 #include <Akonadi/Contact/ContactEditorDialog>
+#include <AkonadiCore/AgentFilterProxyModel>
+#include <AkonadiCore/AgentInstanceCreateJob>
+#include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/CollectionFetchScope>
+#include <AkonadiWidgets/AgentTypeDialog>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -30,14 +30,11 @@ CreateNewContactJob::CreateNewContactJob(QWidget *parentWidget, QObject *parent)
 {
 }
 
-CreateNewContactJob::~CreateNewContactJob()
-= default;
+CreateNewContactJob::~CreateNewContactJob() = default;
 
 void CreateNewContactJob::start()
 {
-    Akonadi::CollectionFetchJob *const addressBookJob
-        = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-                                          Akonadi::CollectionFetchJob::Recursive);
+    auto const addressBookJob = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive);
 
     addressBookJob->fetchScope().setContentMimeTypes(QStringList() << KContacts::Addressee::mimeType());
     connect(addressBookJob, &KJob::result, this, &CreateNewContactJob::slotCollectionsFetched);
@@ -58,7 +55,7 @@ void CreateNewContactJob::slotCollectionsFetched(KJob *job)
 
     const Akonadi::Collection::List lstAddressCollection = addressBookJob->collections();
     for (const Akonadi::Collection &collection : lstAddressCollection) {
-        if (Akonadi::Collection::CanCreateItem &collection.rights()) {
+        if (Akonadi::Collection::CanCreateItem & collection.rights()) {
             canCreateItemCollections.append(collection);
         }
     }
@@ -73,17 +70,17 @@ void CreateNewContactJob::slotCollectionsFetched(KJob *job)
             const Akonadi::AgentType agentType = dlg->agentType();
             delete dlg;
             if (agentType.isValid()) {
-                auto *job = new Akonadi::AgentInstanceCreateJob(agentType, this);
+                auto job = new Akonadi::AgentInstanceCreateJob(agentType, this);
                 connect(job, &Akonadi::AgentInstanceCreateJob::result, this, &CreateNewContactJob::slotResourceCreationDone);
                 job->configure(mParentWidget);
                 job->start();
                 return;
-            } else { //if agent is not valid => return error and finish job
+            } else { // if agent is not valid => return error and finish job
                 setError(UserDefinedError);
                 emitResult();
                 return;
             }
-        } else { //dialog canceled => return error and finish job
+        } else { // dialog canceled => return error and finish job
             delete dlg;
             setError(UserDefinedError);
             emitResult();
@@ -117,7 +114,7 @@ void CreateNewContactJob::createContact()
 
 void CreateNewContactJob::contactStored(const Akonadi::Item &item)
 {
-    Q_UNUSED(item);
+    Q_UNUSED(item)
     PimCommon::BroadcastStatus::instance()->setStatusMsg(i18n("Contact created successfully"));
 }
 
