@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILLCOMPOSERJOB_H
-#define FILLCOMPOSERJOB_H
+#pragma once
 
 #include <KMime/Message>
 #include <QObject>
@@ -85,4 +84,3 @@ private:
     KMime::Message::Ptr mMsg = nullptr;
 };
 
-#endif // FILLCOMPOSERJOB_H
