@@ -14,6 +14,7 @@
 // widgets like a toolbar.
 
 #include "kmreadermainwin.h"
+#include "job/composenewmessagejob.h"
 #include "kmmainwidget.h"
 #include "kmreaderwin.h"
 #include "widgets/zoomlabelwidget.h"
@@ -355,10 +356,28 @@ void KMReaderMainWin::slotForwardAttachedMessage()
         command = new KMForwardAttachedCommand(this, mReaderWin->messageItem());
     }
 
-    connect(command, &KMTrashMsgCommand::completed, this, &KMReaderMainWin::slotReplyOrForwardFinished);
+    connect(command, &KMForwardAttachedCommand::completed, this, &KMReaderMainWin::slotReplyOrForwardFinished);
     command->start();
 }
 
+void KMReaderMainWin::slotNewMessageToRecipients()
+{
+    auto *job = new ComposeNewMessageJob;
+
+    const Akonadi::Collection parentCol = mReaderWin->messageItem().parentCollection();
+    if (parentCol.isValid()) {
+        job->setCurrentCollection(parentCol);
+
+        QSharedPointer<FolderSettings> fd = FolderSettings::forCollection(parentCol, false);
+        if (fd) {
+            job->setFolderSettings(fd);
+        }
+    }
+
+    job->setRecipientsFromMessage(mReaderWin->messageItem());
+    job->start();
+}
+
 void KMReaderMainWin::slotRedirectMessage()
 {
     const Akonadi::Item currentItem = mReaderWin->messageItem();
@@ -517,10 +536,12 @@ QAction *KMReaderMainWin::copyActionMenu(QMenu *menu)
 {
     KMMainWidget *mainwin = kmkernel->getKMMainWidget();
     if (mainwin) {
-        auto action = new KActionMenu(menu);
-        action->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
-        action->setText(i18n("Copy Message To..."));
-        mainwin->standardMailActionManager()->standardActionManager()->createActionFolderMenu(action->menu(), Akonadi::StandardActionManager::CopyItemToMenu);
+        Akonadi::StandardActionManager *manager = mainwin->standardMailActionManager()->standardActionManager();
+        const auto *mainWinAction = manager->action(Akonadi::StandardActionManager::CopyItemToMenu);
+        auto *action = new KActionMenu(menu);
+        action->setIcon(mainWinAction->icon());
+        action->setText(mainWinAction->text());
+        manager->createActionFolderMenu(action->menu(), Akonadi::StandardActionManager::CopyItemToMenu);
         connect(action->menu(), &QMenu::triggered, this, &KMReaderMainWin::slotCopyItem);
         return action;
     }
@@ -531,12 +552,13 @@ QAction *KMReaderMainWin::moveActionMenu(QMenu *menu)
 {
     KMMainWidget *mainwin = kmkernel->getKMMainWidget();
     if (mainwin) {
-        auto action = new KActionMenu(menu);
-        action->setText(i18n("Move Message To..."));
-        action->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
-        mainwin->standardMailActionManager()->standardActionManager()->createActionFolderMenu(action->menu(), Akonadi::StandardActionManager::MoveItemToMenu);
+        Akonadi::StandardActionManager *manager = mainwin->standardMailActionManager()->standardActionManager();
+        const auto *mainWinAction = manager->action(Akonadi::StandardActionManager::MoveItemToMenu);
+        auto *action = new KActionMenu(menu);
+        action->setIcon(mainWinAction->icon());
+        action->setText(mainWinAction->text());
+        manager->createActionFolderMenu(action->menu(), Akonadi::StandardActionManager::MoveItemToMenu);
         connect(action->menu(), &QMenu::triggered, this, &KMReaderMainWin::slotMoveItem);
-
         return action;
     }
     return nullptr;
@@ -546,7 +568,7 @@ void KMReaderMainWin::slotMoveItem(QAction *action)
 {
     if (action) {
         const QModelIndex index = action->data().toModelIndex();
-        const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const auto collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         copyOrMoveItem(collection, true);
     }
 }
@@ -565,13 +587,18 @@ void KMReaderMainWin::copyOrMoveItem(const Akonadi::Collection &collection, bool
         auto job = new Akonadi::ItemCreateJob(mMsg, collection, this);
         connect(job, &KJob::result, this, &KMReaderMainWin::slotCopyMoveResult);
     }
+
+    KMMainWidget *mainwin = kmkernel->getKMMainWidget();
+    if (mainwin) {
+        mainwin->standardMailActionManager()->standardActionManager()->addRecentCollection(collection.id());
+    }
 }
 
 void KMReaderMainWin::slotCopyItem(QAction *action)
 {
     if (action) {
         const QModelIndex index = action->data().toModelIndex();
-        const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const auto collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         copyOrMoveItem(collection, false);
     }
 }
@@ -618,11 +645,11 @@ void KMReaderMainWin::slotContactSearchJobForMessagePopupDone(KJob *job)
         mReaderWin->clearContactItem();
     }
 
-    const Akonadi::Item msg = job->property("msg").value<Akonadi::Item>();
+    const auto msg = job->property("msg").value<Akonadi::Item>();
     const QPoint aPoint = job->property("point").toPoint();
     const QUrl imageUrl = job->property("imageUrl").toUrl();
     const QUrl url = job->property("url").toUrl();
-    const WebEngineViewer::WebHitTestResult result = job->property("webhitresult").value<WebEngineViewer::WebHitTestResult>();
+    const auto result = job->property("webhitresult").value<WebEngineViewer::WebHitTestResult>();
 
     showMessagePopup(msg, url, imageUrl, aPoint, contactAlreadyExists, uniqueContactFound, result);
 }
