@@ -9,24 +9,17 @@
 
 #include "kcmkontactsummary.h"
 
-#include <KontactInterface/Plugin>
-
 #include <KAboutData>
 #include <KConfig>
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <KPluginInfo>
-#include <KService>
-#include <KServiceTypeTrader>
+#include <KPluginMetaData>
+#include <KontactInterface/Plugin>
 #include <QIcon>
 
 #include <QLabel>
 #include <QVBoxLayout>
-extern "C" {
-Q_DECL_EXPORT KCModule *create_kontactsummary(QWidget *parent, const char *)
-{
-    return new KCMKontactSummary(parent);
-}
-}
 
 class PluginItem : public QTreeWidgetItem
 {
@@ -72,8 +65,10 @@ PluginView::PluginView(QWidget *parent)
 
 PluginView::~PluginView() = default;
 
-KCMKontactSummary::KCMKontactSummary(QWidget *parent)
-    : KCModule(parent)
+K_PLUGIN_CLASS_WITH_JSON(KCMKontactSummary, "kcmkontactsummary.json")
+
+KCMKontactSummary::KCMKontactSummary(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     setButtons(NoAdditionalButton);
     auto layout = new QVBoxLayout(this);
@@ -101,8 +96,9 @@ KCMKontactSummary::KCMKontactSummary(QWidget *parent)
 
 void KCMKontactSummary::load()
 {
-    KService::List offers =
-        KServiceTypeTrader::self()->query(QStringLiteral("Kontact/Plugin"), QStringLiteral("[X-KDE-KontactPluginVersion] == %1").arg(KONTACT_PLUGIN_VERSION));
+    const QVector<KPluginMetaData> pluginMetaDatas = KPluginLoader::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
+        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+    });
 
     QStringList activeSummaries;
 
@@ -124,10 +120,11 @@ void KCMKontactSummary::load()
 
     mPluginView->clear();
 
-    KPluginInfo::List pluginList = KPluginInfo::fromServices(offers, KConfigGroup(&config, "Plugins"));
+    KPluginInfo::List pluginList = KPluginInfo::fromMetaData(pluginMetaDatas);
     KPluginInfo::List::Iterator it;
     KPluginInfo::List::Iterator end(pluginList.end());
     for (it = pluginList.begin(); it != end; ++it) {
+        it->setConfig(KConfigGroup(&config, "Plugins"));
         it->load();
 
         if (!it->isPluginEnabled()) {
@@ -164,3 +161,4 @@ void KCMKontactSummary::save()
     KConfigGroup grp(&config, QString());
     grp.writeEntry("ActiveSummaries", activeSummaries);
 }
+#include "kcmkontactsummary.moc"
