@@ -9,14 +9,14 @@
 
 #include "undostack.h"
 
-#include "kmmainwin.h"
 #include "kmkernel.h"
-#include <KJob>
+#include "kmmainwin.h"
 #include <AkonadiCore/itemmovejob.h>
+#include <KJob>
 
-#include <KMessageBox>
-#include <KLocalizedString>
 #include "kmail_debug.h"
+#include <KLocalizedString>
+#include <KMessageBox>
 
 using namespace KMail;
 
@@ -48,13 +48,13 @@ QString UndoStack::undoInfo() const
         UndoInfo *info = mStack.first();
         return info->moveToTrash ? i18n("Move To Trash") : i18np("Move Message", "Move Messages", info->items.count());
     } else {
-        return QString();
+        return {};
     }
 }
 
 int UndoStack::newUndoAction(const Akonadi::Collection &srcFolder, const Akonadi::Collection &destFolder)
 {
-    auto *info = new UndoInfo;
+    auto info = new UndoInfo;
     info->id = ++mLastId;
     info->srcFolder = srcFolder;
     info->destFolder = destFolder;
@@ -95,7 +95,7 @@ void UndoStack::undo()
     if (!mStack.isEmpty()) {
         UndoInfo *info = mStack.takeFirst();
         Q_EMIT undoStackChanged();
-        auto *job = new Akonadi::ItemMoveJob(info->items, info->srcFolder, this);
+        auto job = new Akonadi::ItemMoveJob(info->items, info->srcFolder, this);
         connect(job, &Akonadi::ItemMoveJob::result, this, &UndoStack::slotMoveResult);
         delete info;
     } else {
@@ -122,9 +122,7 @@ void UndoStack::folderDestroyed(const Akonadi::Collection &folder)
     QList<UndoInfo *>::iterator it = mStack.begin();
     while (it != mStack.end()) {
         UndoInfo *info = *it;
-        if (info
-            && ((info->srcFolder == folder)
-                || (info->destFolder == folder))) {
+        if (info && ((info->srcFolder == folder) || (info->destFolder == folder))) {
             delete info;
             it = mStack.erase(it);
         } else {
